@@ -38,12 +38,13 @@ class DocumentContextEnum(StrEnum):
 class DocumentCategoryEnum(StrEnum):
     getting_started = "getting_started"
     api_reference = "api_reference"
-    tutorials = "tutorials"
-    code_examples = "code_examples"
-    use_cases = "use_cases"
+    tutorial = "tutorial"
+    code_example = "code_example"
+    code_example_output = "code_example_output"
+    use_case = "use_case"
     troubleshooting = "troubleshooting"
     changelog = "changelog"
-    best_practices = "best_practices"
+    best_practice = "best_practice"
     specification = "specification"
     service_level_agreement = "service_level_agreement"
     terms_of_service = "terms_of_service"
@@ -255,18 +256,6 @@ class Document(BaseModel):
         default=False,
         description="Whether document is publicly accessible without authentication",
     )
-    requirements: list[str] | None = Field(
-        default=None,
-        description="Required packages/modules for running this code example (e.g., ['openai', 'httpx'])",
-    )
-    expect: str | None = Field(
-        default=None,
-        max_length=500,
-        description=(
-            "Expected output substring for code example validation. "
-            "If specified, test passes only if stdout contains this string."
-        ),
-    )
 
 
 class RateLimit(BaseModel):
